@@ -30,8 +30,6 @@
 #include <stdlib.h>
 #include <time.h>
 #include <png.h>
-/* setjmp.h needs to be included after png.h */
-#include <setjmp.h>
 
 #include "pm_c_util.h"
 #include "mallocvar.h"
@@ -84,9 +82,9 @@ parseChromaOpt(const char *         const chromaOpt,
                    &chromaP->gx, &chromaP->gy,
                    &chromaP->bx, &chromaP->by);
 
-    if (count != 6)
-        pm_error("Invalid syntax for the -rgb option value '%s'.  "
-                 "Should be 6 floating point number: "
+    if (count != 8)
+        pm_error("Invalid syntax for the -chroma option value '%s'.  "
+                 "Should be 8 floating point numbers: "
                  "x and y for each of white, red, green, and blue",
                  chromaOpt);
 }
@@ -529,7 +527,6 @@ doZtxtChunkSet(struct pngx * const pngxP,
 
 
 
-
 static void
 doItxtChunkSet(struct pngx * const pngxP,
                const char *  const textFileName) {
